# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: auth.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'auth.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nauth.proto\x12\x04\x61uth\"D\n\x0fRegisterRequest\x12\x10\n\x08username\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\t\"#\n\x10RegisterResponse\x12\x0f\n\x07user_id\x18\x01 \x01(\t\"/\n\x0cLoginRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\"<\n\rLoginResponse\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\x15\n\rrefresh_token\x18\x02 \x01(\t\"-\n\x14RefreshTokensRequest\x12\x15\n\rrefresh_token\x18\x01 \x01(\t\"D\n\x15RefreshTokensResponse\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\x15\n\rrefresh_token\x18\x02 \x01(\t\"&\n\rLogoutRequest\x12\x15\n\rrefresh_token\x18\x01 \x01(\t\"!\n\x0eLogoutResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"\x1f\n\x0cGetMeRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\"V\n\rGetMeResponse\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x10\n\x08username\x18\x02 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\x12\x13\n\x0bis_verified\x18\x04 \x01(\x08\"&\n\x15GetUserByEmailRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\"J\n\x16GetUserByEmailResponse\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x10\n\x08username\x18\x02 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\",\n\x14ValidateTokenRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\"X\n\x15ValidateTokenResponse\x12\r\n\x05valid\x18\x01 \x01(\x08\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\x12\x10\n\x08username\x18\x04 \x01(\t\"\x1f\n\x0eSendOtpRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\"\"\n\x0fSendOtpResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"/\n\x10VerifyOtpRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\"$\n\x11VerifyOtpResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x32\xb8\x04\n\x0b\x41uthService\x12\x39\n\x08Register\x12\x15.auth.RegisterRequest\x1a\x16.auth.RegisterResponse\x12\x30\n\x05Login\x12\x12.auth.LoginRequest\x1a\x13.auth.LoginResponse\x12H\n\rRefreshTokens\x12\x1a.auth.RefreshTokensRequest\x1a\x1b.auth.RefreshTokensResponse\x12\x33\n\x06Logout\x12\x13.auth.LogoutRequest\x1a\x14.auth.LogoutResponse\x12\x30\n\x05GetMe\x12\x12.auth.GetMeRequest\x1a\x13.auth.GetMeResponse\x12K\n\x0eGetUserByEmail\x12\x1b.auth.GetUserByEmailRequest\x1a\x1c.auth.GetUserByEmailResponse\x12H\n\rValidateToken\x12\x1a.auth.ValidateTokenRequest\x1a\x1b.auth.ValidateTokenResponse\x12\x36\n\x07SendOtp\x12\x14.auth.SendOtpRequest\x1a\x15.auth.SendOtpResponse\x12<\n\tVerifyOtp\x12\x16.auth.VerifyOtpRequest\x1a\x17.auth.VerifyOtpResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'auth_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_REGISTERREQUEST']._serialized_start=20
  _globals['_REGISTERREQUEST']._serialized_end=88
  _globals['_REGISTERRESPONSE']._serialized_start=90
  _globals['_REGISTERRESPONSE']._serialized_end=125
  _globals['_LOGINREQUEST']._serialized_start=127
  _globals['_LOGINREQUEST']._serialized_end=174
  _globals['_LOGINRESPONSE']._serialized_start=176
  _globals['_LOGINRESPONSE']._serialized_end=236
  _globals['_REFRESHTOKENSREQUEST']._serialized_start=238
  _globals['_REFRESHTOKENSREQUEST']._serialized_end=283
  _globals['_REFRESHTOKENSRESPONSE']._serialized_start=285
  _globals['_REFRESHTOKENSRESPONSE']._serialized_end=353
  _globals['_LOGOUTREQUEST']._serialized_start=355
  _globals['_LOGOUTREQUEST']._serialized_end=393
  _globals['_LOGOUTRESPONSE']._serialized_start=395
  _globals['_LOGOUTRESPONSE']._serialized_end=428
  _globals['_GETMEREQUEST']._serialized_start=430
  _globals['_GETMEREQUEST']._serialized_end=461
  _globals['_GETMERESPONSE']._serialized_start=463
  _globals['_GETMERESPONSE']._serialized_end=549
  _globals['_GETUSERBYEMAILREQUEST']._serialized_start=551
  _globals['_GETUSERBYEMAILREQUEST']._serialized_end=589
  _globals['_GETUSERBYEMAILRESPONSE']._serialized_start=591
  _globals['_GETUSERBYEMAILRESPONSE']._serialized_end=665
  _globals['_VALIDATETOKENREQUEST']._serialized_start=667
  _globals['_VALIDATETOKENREQUEST']._serialized_end=711
  _globals['_VALIDATETOKENRESPONSE']._serialized_start=713
  _globals['_VALIDATETOKENRESPONSE']._serialized_end=801
  _globals['_SENDOTPREQUEST']._serialized_start=803
  _globals['_SENDOTPREQUEST']._serialized_end=834
  _globals['_SENDOTPRESPONSE']._serialized_start=836
  _globals['_SENDOTPRESPONSE']._serialized_end=870
  _globals['_VERIFYOTPREQUEST']._serialized_start=872
  _globals['_VERIFYOTPREQUEST']._serialized_end=919
  _globals['_VERIFYOTPRESPONSE']._serialized_start=921
  _globals['_VERIFYOTPRESPONSE']._serialized_end=957
  _globals['_AUTHSERVICE']._serialized_start=960
  _globals['_AUTHSERVICE']._serialized_end=1528
# @@protoc_insertion_point(module_scope)
